@@ -1,18 +1,7 @@
 import json
 import os
 import warnings
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    List,
-    Optional,
-    Type,
-    Union,
-    cast,
-    final,
-)
+from typing import TYPE_CHECKING, Any, Callable, Optional, Union, cast, final
 
 import cloudpickle
 import numpy as np
@@ -38,7 +27,7 @@ if TYPE_CHECKING:
     import transformers
 
 
-def get_requirements_from_task(task: str, spcs_only: bool = False) -> List[model_env.ModelDependency]:
+def get_requirements_from_task(task: str, spcs_only: bool = False) -> list[model_env.ModelDependency]:
     # Text
     if task in [
         "conversational",
@@ -84,7 +73,7 @@ class HuggingFacePipelineHandler(
     HANDLER_TYPE = "huggingface_pipeline"
     HANDLER_VERSION = "2023-12-01"
     _MIN_SNOWPARK_ML_VERSION = "1.0.12"
-    _HANDLER_MIGRATOR_PLANS: Dict[str, Type[base_migrator.BaseModelHandlerMigrator]] = {}
+    _HANDLER_MIGRATOR_PLANS: dict[str, type[base_migrator.BaseModelHandlerMigrator]] = {}
 
     MODEL_BLOB_FILE_OR_DIR = "model"
     ADDITIONAL_CONFIG_FILE = "pipeline_config.pt"
@@ -250,20 +239,17 @@ class HuggingFacePipelineHandler(
             task, spcs_only=(not type_utils.LazyType("transformers.Pipeline").isinstance(model))
         )
         if framework is None or framework == "pt":
-            # Since we set default cuda version to be 11.8, to make sure it works with GPU, we need to have a default
-            # Pytorch version that works with CUDA 11.8 as well. This is required for huggingface pipelines only as
-            # users are not required to install pytorch locally if they are using the wrapper.
             pkgs_requirements.append(model_env.ModelDependency(requirement="pytorch", pip_name="torch"))
         elif framework == "tf":
             pkgs_requirements.append(model_env.ModelDependency(requirement="tensorflow", pip_name="tensorflow"))
         model_meta.env.include_if_absent(
             pkgs_requirements, check_local_version=(type_utils.LazyType("transformers.Pipeline").isinstance(model))
         )
-        model_meta.env.cuda_version = kwargs.get("cuda_version", model_env.DEFAULT_CUDA_VERSION)
+        model_meta.env.cuda_version = kwargs.get("cuda_version", handlers_utils.get_default_cuda_version())
 
     @staticmethod
-    def _get_device_config(**kwargs: Unpack[model_types.HuggingFaceLoadOptions]) -> Dict[str, str]:
-        device_config: Dict[str, Any] = {}
+    def _get_device_config(**kwargs: Unpack[model_types.HuggingFaceLoadOptions]) -> dict[str, str]:
+        device_config: dict[str, Any] = {}
         cuda_visible_devices = os.environ.get("CUDA_VISIBLE_DEVICES", None)
         gpu_nums = 0
         if cuda_visible_devices is not None:
@@ -369,7 +355,7 @@ class HuggingFacePipelineHandler(
         def _create_custom_model(
             raw_model: "transformers.Pipeline",
             model_meta: model_meta_api.ModelMetadata,
-        ) -> Type[custom_model.CustomModel]:
+        ) -> type[custom_model.CustomModel]:
             def fn_factory(
                 raw_model: "transformers.Pipeline",
                 signature: model_signature.ModelSignature,
